import sys
import os
import random
from PySide6.QtWidgets import *
from PySide6.QtCore import *
from PySide6.QtGui import *


class Fix:
    def analyse_code(self, contents: str) -> tuple:
        """
        Return list of lines, pyside2 path line number, indentation.

            :param str contents: code in __init__.py
        """
        lines = contents.splitlines(keepends=True)
        # locate pyside_package_dir line index
        pkg_dir = 'os.path.abspath(os.path.dirname(__file__))'
        for index, line in enumerate(lines):
            if pkg_dir in line:
                break

        # return lines, line index, indentation
        return lines, index, ' ' * (len(line.rstrip()) - len(line.strip()))

    def insert_lines(self, contents: str) -> list:
        """
        Insert lines adding platforms plugin to PATH,
        return replaced list of lines of code.

            :param str contents: code in __init__.py
            :return: replaced list of lines of code
        """
        lines, position, indentation = self.analyse_code(contents)
        new_lines = (
                lines[position] + '\n' +
                indentation + '# add platforms plugin to PATH\n' +
                indentation + 'platforms_dir = ' +
                'os.path.join(pyside_package_dir, "plugins", "platforms")\n' +
                indentation +
                'os.environ["QT_QPA_PLATFORM_PLUGIN_PATH"] = platforms_dir\n')

        # insert lines
        lines[position] = new_lines
        return lines

    def add_plugins_to_PATH(self, file_path):
        """
        Add platforms plugin to PATH to avoid load error.

            :param str file_path: __init__.py path in PySide2 toplevel package
        """
        # open __init__.py
        with open(file_path, encoding='utf-8') as f:
            contents = f.read()

        # insert lines
        lines = self.insert_lines(contents)

        # save changes to __init__.py
        code = ''.join(lines)
        with open(file_path, 'w', encoding='utf-8') as f:
            f.write(code)

    def start_fix(self):
        """Glitch fixing entry."""
        import PySide6
        pyside6_init_module = PySide6.__file__
        self.add_plugins_to_PATH(pyside6_init_module)


fix = Fix()
fix.start_fix()


class Ui_Cards(object):
    def setupUi(self, Cards):
        if not Cards.objectName():
            Cards.setObjectName(u"Cards")
        Cards.resize(1040, 793)
        self.centralwidget = QWidget(Cards)
        self.centralwidget.setObjectName(u"centralwidget")
        self.gridLayoutWidget = QWidget(self.centralwidget)
        self.gridLayoutWidget.setObjectName(u"gridLayoutWidget")
        self.gridLayoutWidget.setGeometry(QRect(10, 110, 1011, 621))
        self.gridLayout = QGridLayout(self.gridLayoutWidget)
        self.gridLayout.setObjectName(u"gridLayout")
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.pbtn07 = QPushButton(self.gridLayoutWidget)
        self.pbtn_img = QButtonGroup(Cards)
        self.pbtn_img.setObjectName(u"pbtn_img")
        self.pbtn_img.addButton(self.pbtn07)
        self.pbtn07.setObjectName(u"pbtn07")

        self.gridLayout.addWidget(self.pbtn07, 1, 2, 1, 1)

        self.pbtn11 = QPushButton(self.gridLayoutWidget)
        self.pbtn_img.addButton(self.pbtn11)
        self.pbtn11.setObjectName(u"pbtn11")

        self.gridLayout.addWidget(self.pbtn11, 2, 2, 1, 1)

        self.pbtn13 = QPushButton(self.gridLayoutWidget)
        self.pbtn_img.addButton(self.pbtn13)
        self.pbtn13.setObjectName(u"pbtn13")

        self.gridLayout.addWidget(self.pbtn13, 0, 4, 1, 1)

        self.pbtn03 = QPushButton(self.gridLayoutWidget)
        self.pbtn_img.addButton(self.pbtn03)
        self.pbtn03.setObjectName(u"pbtn03")

        self.gridLayout.addWidget(self.pbtn03, 0, 2, 1, 1)

        self.pbtn18 = QPushButton(self.gridLayoutWidget)
        self.pbtn_img.addButton(self.pbtn18)
        self.pbtn18.setObjectName(u"pbtn18")

        self.gridLayout.addWidget(self.pbtn18, 3, 0, 1, 1)

        self.pbtn17 = QPushButton(self.gridLayoutWidget)
        self.pbtn17.setObjectName(u"pbtn17")
        self.pbtn_img.addButton(self.pbtn17)

        self.gridLayout.addWidget(self.pbtn17, 2, 4, 1, 1)

        self.pbtn08 = QPushButton(self.gridLayoutWidget)
        self.pbtn_img.addButton(self.pbtn08)
        self.pbtn08.setObjectName(u"pbtn08")

        self.gridLayout.addWidget(self.pbtn08, 1, 3, 1, 1)

        self.pbtn10 = QPushButton(self.gridLayoutWidget)
        self.pbtn_img.addButton(self.pbtn10)
        self.pbtn10.setObjectName(u"pbtn10")

        self.gridLayout.addWidget(self.pbtn10, 2, 1, 1, 1)

        self.pbtn12 = QPushButton(self.gridLayoutWidget)
        self.pbtn_img.addButton(self.pbtn12)
        self.pbtn12.setObjectName(u"pbtn12")

        self.gridLayout.addWidget(self.pbtn12, 2, 3, 1, 1)

        self.pbtn19 = QPushButton(self.gridLayoutWidget)
        self.pbtn_img.addButton(self.pbtn19)
        self.pbtn19.setObjectName(u"pbtn19")

        self.gridLayout.addWidget(self.pbtn19, 3, 1, 1, 1)

        self.pbtn02 = QPushButton(self.gridLayoutWidget)
        self.pbtn_img.addButton(self.pbtn02)
        self.pbtn02.setObjectName(u"pbtn02")

        self.gridLayout.addWidget(self.pbtn02, 0, 1, 1, 1)

        self.pbtn05 = QPushButton(self.gridLayoutWidget)
        self.pbtn_img.addButton(self.pbtn05)
        self.pbtn05.setObjectName(u"pbtn05")

        self.gridLayout.addWidget(self.pbtn05, 1, 0, 1, 1)

        self.pbtn21 = QPushButton(self.gridLayoutWidget)
        self.pbtn_img.addButton(self.pbtn21)
        self.pbtn21.setObjectName(u"pbtn21")

        self.gridLayout.addWidget(self.pbtn21, 3, 3, 1, 1)

        self.pbtn20 = QPushButton(self.gridLayoutWidget)
        self.pbtn_img.addButton(self.pbtn20)
        self.pbtn20.setObjectName(u"pbtn20")

        self.gridLayout.addWidget(self.pbtn20, 3, 2, 1, 1)

        self.pbtn09 = QPushButton(self.gridLayoutWidget)
        self.pbtn_img.addButton(self.pbtn09)
        self.pbtn09.setObjectName(u"pbtn09")

        self.gridLayout.addWidget(self.pbtn09, 2, 0, 1, 1)

        self.pbtn06 = QPushButton(self.gridLayoutWidget)
        self.pbtn_img.addButton(self.pbtn06)
        self.pbtn06.setObjectName(u"pbtn06")

        self.gridLayout.addWidget(self.pbtn06, 1, 1, 1, 1)

        self.pbtn24 = QPushButton(self.gridLayoutWidget)
        self.pbtn_img.addButton(self.pbtn24)
        self.pbtn24.setObjectName(u"pbtn24")

        self.gridLayout.addWidget(self.pbtn24, 1, 4, 1, 1)

        self.pbtn04 = QPushButton(self.gridLayoutWidget)
        self.pbtn_img.addButton(self.pbtn04)
        self.pbtn04.setObjectName(u"pbtn04")

        self.gridLayout.addWidget(self.pbtn04, 0, 3, 1, 1)

        self.pbtn22 = QPushButton(self.gridLayoutWidget)
        self.pbtn_img.addButton(self.pbtn22)
        self.pbtn22.setObjectName(u"pbtn22")

        self.gridLayout.addWidget(self.pbtn22, 3, 4, 1, 1)

        self.pbtn01 = QPushButton(self.gridLayoutWidget)
        self.pbtn_img.addButton(self.pbtn01)
        self.pbtn01.setObjectName(u"pbtn01")

        self.gridLayout.addWidget(self.pbtn01, 0, 0, 1, 1)

        self.pbtn23 = QPushButton(self.gridLayoutWidget)
        self.pbtn_img.addButton(self.pbtn23)
        self.pbtn23.setObjectName(u"pbtn23")

        self.gridLayout.addWidget(self.pbtn23, 0, 5, 1, 1)

        self.pbtn14 = QPushButton(self.gridLayoutWidget)
        self.pbtn_img.addButton(self.pbtn14)
        self.pbtn14.setObjectName(u"pbtn14")

        self.gridLayout.addWidget(self.pbtn14, 1, 5, 1, 1)

        self.pbtn15 = QPushButton(self.gridLayoutWidget)
        self.pbtn_img.addButton(self.pbtn15)
        self.pbtn15.setObjectName(u"pbtn15")

        self.gridLayout.addWidget(self.pbtn15, 2, 5, 1, 1)

        self.pbtn16 = QPushButton(self.gridLayoutWidget)
        self.pbtn_img.addButton(self.pbtn16)
        self.pbtn16.setObjectName(u"pbtn16")

        self.gridLayout.addWidget(self.pbtn16, 3, 5, 1, 1)

        self.lcd_time = QLCDNumber(self.centralwidget)
        self.lcd_time.setObjectName(u"lcd_time")
        self.lcd_time.setGeometry(QRect(390, 10, 221, 91))
        Cards.setCentralWidget(self.centralwidget)

        self.retranslateUi(Cards)

        QMetaObject.connectSlotsByName(Cards)
    # setupUi

    def retranslateUi(self, Cards):
        Cards.setWindowTitle(
            QCoreApplication.translate("Cards", u"\u8bb0\u5fc6\u7ffb\u724c", None))
        self.pbtn07.setText(QCoreApplication.translate("Cards",
                                                       u"PushButton", None))
        self.pbtn11.setText(QCoreApplication.translate("Cards",
                                                       u"PushButton", None))
        self.pbtn13.setText(QCoreApplication.translate("Cards",
                                                       u"PushButton", None))
        self.pbtn03.setText(QCoreApplication.translate("Cards",
                                                       u"PushButton", None))
        self.pbtn18.setText(QCoreApplication.translate("Cards",
                                                       u"PushButton", None))
        self.pbtn17.setText(QCoreApplication.translate("Cards",
                                                       u"PushButton", None))
        self.pbtn08.setText(QCoreApplication.translate("Cards",
                                                       u"PushButton", None))
        self.pbtn10.setText(QCoreApplication.translate("Cards",
                                                       u"PushButton", None))
        self.pbtn12.setText(QCoreApplication.translate("Cards",
                                                       u"PushButton", None))
        self.pbtn19.setText(QCoreApplication.translate("Cards",
                                                       u"PushButton", None))
        self.pbtn02.setText(QCoreApplication.translate("Cards",
                                                       u"PushButton", None))
        self.pbtn05.setText(QCoreApplication.translate("Cards",
                                                       u"PushButton", None))
        self.pbtn21.setText(QCoreApplication.translate("Cards",
                                                       u"PushButton", None))
        self.pbtn20.setText(QCoreApplication.translate("Cards",
                                                       u"PushButton", None))
        self.pbtn09.setText(QCoreApplication.translate("Cards",
                                                       u"PushButton", None))
        self.pbtn06.setText(QCoreApplication.translate("Cards",
                                                       u"PushButton", None))
        self.pbtn24.setText(QCoreApplication.translate("Cards",
                                                       u"PushButton", None))
        self.pbtn04.setText(QCoreApplication.translate("Cards",
                                                       u"PushButton", None))
        self.pbtn22.setText(QCoreApplication.translate("Cards",
                                                       u"PushButton", None))
        self.pbtn01.setText(QCoreApplication.translate("Cards",
                                                       u"PushButton", None))
        self.pbtn23.setText(QCoreApplication.translate("Cards",
                                                       u"PushButton", None))
        self.pbtn14.setText(QCoreApplication.translate("Cards",
                                                       u"PushButton", None))
        self.pbtn15.setText(QCoreApplication.translate("Cards",
                                                       u"PushButton", None))
        self.pbtn16.setText(QCoreApplication.translate("Cards",
                                                       u"PushButton", None))
    # retranslateUi


class Cards(QMainWindow, Ui_Cards):
    def __init__(self):
        super().__init__()
        self.setupUi(self)
        self.init_button()
        self.init_img()
        self.show()
        self.clicked_num = 0
        self.match_img = {
            1: {
                "pbtn": None,
                "pbtn_img": None
            },
            2: {
                "pbtn": None,
                "pbtn_img": None
            },
        }
        self.first_clicked = True
        self.time = 0
        self.right_count = 0
        self.pbtn_img.buttonClicked.connect(self.pbtn_func)

    def init_button(self):
        pbtn_list = self.pbtn_img.buttons()
        for btn in pbtn_list:
            btn.setText("")
            btn.setIcon(QIcon("images_cards/bg.png"))
            btn.setIconSize(QSize(150, 150))
            btn.setCheckable(True)

    def init_img(self):
        image_type = ['.png', '.jpg', '.bmp', '.jpeg']
        files = os.listdir("images_cards")
        all_imgs = []
        for file in files:
            ext = os.path.splitext(file)[-1]
            if ext in image_type:
                all_imgs.append("images_cards" + os.sep + file)

        random_imgs = random.sample(all_imgs, 12)
        grid_imgs = random_imgs + random_imgs
        random.shuffle(grid_imgs)
        pbtn_list = self.pbtn_img.buttons()
        self.grids = dict(zip(pbtn_list, grid_imgs))

    def pbtn_func(self):
        if self.first_clicked:
            self.first_clicked = False
            self.timer = QTimer()
            self.timer.timeout.connect(self.update_time)
            self.timer.start(1000)

        if self.clicked_num < 2:
            QApplication.processEvents()
            pbtn = self.pbtn_img.checkedButton()
            if pbtn != self.match_img[1]["pbtn"] and \
                    pbtn in self.pbtn_img.buttons():
                self.clicked_num += 1
                pbtn.setIcon(QIcon(self.grids[pbtn]))
                self.match_img[self.clicked_num]["pbtn"] = pbtn
                self.match_img[self.clicked_num]["pbtn_img"] = self.grids[pbtn]
                timer = QTimer()
                timer.singleShot(300, self.judge)

    def judge(self):
        if self.clicked_num == 2:
            self.clicked_num = 0
            if self.match_img[1]["pbtn_img"] != self.match_img[2]["pbtn_img"]:
                self.match_img[1]["pbtn"].setIcon(QIcon("images_cards/bg.png"))
                self.match_img[2]["pbtn"].setIcon(QIcon("images_cards/bg.png"))
            else:
                self.pbtn_img.removeButton(self.match_img[1]["pbtn"])
                self.pbtn_img.removeButton(self.match_img[2]["pbtn"])
                self.right_count += 1
                if self.right_count == 12:
                    self.timer.stop()
            self.match_img[1]["pbtn"] = self.match_img[2]["pbtn"] = None

    def update_time(self):
        self.time += 1
        self.lcd_time.display(self.time)


def main():
    app = QApplication(sys.argv)
    window = Cards()
    sys.exit(app.exec_())


if __name__ == "__main__":
    main()



from PIL import Image, ImageQt
import random
from PySide6.QtWidgets import*
from PySide6.QtCore import*
from PySide6.QtGui import*
import sys


class Fix:
    def analyse_code(self, contents: str) -> tuple:
        lines = contents.splitlines(keepends=True)
        # locate pyside_package_dir line index
        pkg_dir = 'os.path.abspath(os.path.dirname(__file__))'
        for index, line in enumerate(lines):
            if pkg_dir in line:
                break

        # return lines, line index, indentation
        return lines, index, ' ' * (len(line.rstrip()) - len(line.strip()))

    def insert_lines(self, contents: str) -> list:
        lines, position, indentation = self.analyse_code(contents)
        new_lines = (
                lines[position] + '\n' +
                indentation + '# add platforms plugin to PATH\n' +
                indentation + 'platforms_dir = ' +
                'os.path.join(pyside_package_dir, "plugins", "platforms")\n' +
                indentation +
                'os.environ["QT_QPA_PLATFORM_PLUGIN_PATH"] = platforms_dir\n')

        # insert lines
        lines[position] = new_lines
        return lines

    def add_plugins_to_PATH(self, file_path):
        # open __init__.py
        with open(file_path, encoding='utf-8') as f:
            contents = f.read()

        # insert lines
        lines = self.insert_lines(contents)

        # save changes to __init__.py
        code = ''.join(lines)
        with open(file_path, 'w', encoding='utf-8') as f:
            f.write(code)

    def start_fix(self):
        """Glitch fixing entry."""
        import PySide6
        PySide6_init_module = PySide6.__file__
        self.add_plugins_to_PATH(PySide6_init_module)


fix = Fix()
fix.start_fix()


class Pic:
    def __init__(self):
        self.color_out = self.randomColor()
        self.board = Image.new("HSV", (500, 500), self.color_out)
        self.randx = random.randint(0, 9) * 50
        self.randy = random.randint(0, 9) * 50
        self.gen_pic()

    def randomColor(self):
        color = (
            random.randint(0, 360),
            random.randint(0, 255), 255
        )
        return color

    def color_in(self):
        self.res = list(self.color_out)
        self.res[0] += random.randint(10, 15)
        self.res = tuple(self.res)
        return self.res

    def colorBright(self):
        self.res = list(self.color_out)
        self.res[2] -= random.randint(0, 15)
        self.res = tuple(self.res)
        return self.res

    def gen_pic(self):
        for y in range(0, 500, 50):
            for x in range(0, 500, 50):
                if x == self.randx and y == self.randy:
                    new_block = Image.new("HSV", (50, 50), self.color_in())
                    self.board.paste(new_block, (x, y))
                else:
                    new_block = Image.new("HSV", (50, 50), self.colorBright())
                    self.board.paste(new_block, (x, y))


class OpsWindow(QMainWindow):
    def __init__(self):
        super().__init__()
        self.show()
        self.setup()

    def setup(self):
        self.new_pic()
        self.width = self.img.width()
        self.height = self.img.height()
        self.resize(self.width, self.height)
        self.painter = QPainter()

    def new_pic(self):
        self.pic = Pic()
        self.img = ImageQt.ImageQt(self.pic.board.convert("RGBA"))
        self.img = QPixmap.fromImage(self.img)

    def paintEvent(self, event):
        self.painter.begin(self)
        self.painter.drawPixmap(0, 0, self.img)
        self.painter.end()

    def mousePressEvent(self, event):
        x = event.x()
        y = event.y()
        tar_x = self.pic.randx
        tar_y = self.pic.randy
        if tar_x <= x <= tar_x + 50 and tar_y <= y <= tar_y + 50:
            QMessageBox.about(self, "恭喜", "correct")
            self.new_pic()
            self.update()
        else:
            QMessageBox.warning(self, "注意", "wrong")


def main():
    app = QApplication(sys.argv)
    window = OpsWindow()
    sys.exit(app.exec_())


if __name__ == "__main__":
    main()



import sys
from PySide6.QtCore import*
from PySide6.QtWidgets import*
from PySide6.QtGui import*
from PIL import Image, ImageQt


class Fix:
    def analyse_code(self, contents: str) -> tuple:
        lines = contents.splitlines(keepends=True)
        # locate pyside_package_dir line index
        pkg_dir = 'os.path.abspath(os.path.dirname(__file__))'
        for index, line in enumerate(lines):
            if pkg_dir in line:
                break

        # return lines, line index, indentation
        return lines, index, ' ' * (len(line.rstrip()) - len(line.strip()))

    def insert_lines(self, contents: str) -> list:
        lines, position, indentation = self.analyse_code(contents)
        new_lines = (
                lines[position] + '\n' +
                indentation + '# add platforms plugin to PATH\n' +
                indentation + 'platforms_dir = ' +
                'os.path.join(pyside_package_dir, "plugins", "platforms")\n' +
                indentation +
                'os.environ["QT_QPA_PLATFORM_PLUGIN_PATH"] = platforms_dir\n')

        # insert lines
        lines[position] = new_lines
        return lines

    def add_plugins_to_PATH(self, file_path):
        # open __init__.py
        with open(file_path, encoding='utf-8') as f:
            contents = f.read()

        # insert lines
        lines = self.insert_lines(contents)

        # save changes to __init__.py
        code = ''.join(lines)
        with open(file_path, 'w', encoding='utf-8') as f:
            f.write(code)

    def start_fix(self):
        """Glitch fixing entry."""
        import PySide6
        PySide6_init_module = PySide6.__file__
        self.add_plugins_to_PATH(PySide6_init_module)


fix = Fix()
fix.start_fix()


class Ui_RGB(object):
    def setupUi(self, RGB):
        if not RGB.objectName():
            RGB.setObjectName(u"RGB")
        RGB.resize(332, 389)
        self.centralwidget = QWidget(RGB)
        self.centralwidget.setObjectName(u"centralwidget")
        self.label = QLabel(self.centralwidget)
        self.label.setObjectName(u"label")
        self.label.setGeometry(QRect(31, 20, 271, 181))
        self.lineEdit = QLineEdit(self.centralwidget)
        self.lineEdit.setObjectName(u"lineEdit")
        self.lineEdit.setGeometry(QRect(22, 220, 291, 31))
        self.widget = QWidget(self.centralwidget)
        self.widget.setObjectName(u"widget")
        self.widget.setGeometry(QRect(20, 260, 291, 121))
        self.verticalLayout = QVBoxLayout(self.widget)
        self.verticalLayout.setObjectName(u"verticalLayout")
        self.verticalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout = QHBoxLayout()
        self.horizontalLayout.setObjectName(u"horizontalLayout")
        self.slider_r = QSlider(self.widget)
        self.slider_r.setObjectName(u"slider_r")
        self.slider_r.setOrientation(Qt.Horizontal)

        self.horizontalLayout.addWidget(self.slider_r)

        self.label_r = QLabel(self.widget)
        self.label_r.setObjectName(u"label_r")
        self.slider_r.setMaximum(255)
        self.slider_r.setOrientation(Qt.Horizontal)

        self.horizontalLayout.addWidget(self.label_r)


        self.verticalLayout.addLayout(self.horizontalLayout)

        self.horizontalLayout_2 = QHBoxLayout()
        self.horizontalLayout_2.setObjectName(u"horizontalLayout_2")
        self.slider_g = QSlider(self.widget)
        self.slider_g.setObjectName(u"slider_g")
        self.slider_g.setMaximum(255)
        self.slider_g.setOrientation(Qt.Horizontal)

        self.horizontalLayout_2.addWidget(self.slider_g)

        self.label_g = QLabel(self.widget)
        self.label_g.setObjectName(u"label_g")

        self.horizontalLayout_2.addWidget(self.label_g)


        self.verticalLayout.addLayout(self.horizontalLayout_2)

        self.horizontalLayout_3 = QHBoxLayout()
        self.horizontalLayout_3.setObjectName(u"horizontalLayout_3")
        self.slider_b = QSlider(self.widget)
        self.slider_b.setObjectName(u"slider_b")
        self.slider_b.setMaximum(255)
        self.slider_b.setOrientation(Qt.Horizontal)
        self.slider_b.setTickPosition(QSlider.NoTicks)

        self.horizontalLayout_3.addWidget(self.slider_b)

        self.label_b = QLabel(self.widget)
        self.label_b.setObjectName(u"label_b")

        self.horizontalLayout_3.addWidget(self.label_b)


        self.verticalLayout.addLayout(self.horizontalLayout_3)

        RGB.setCentralWidget(self.centralwidget)

        self.retranslateUi(RGB)

        QMetaObject.connectSlotsByName(RGB)
    # setupUi

    def retranslateUi(self, RGB):
        RGB.setWindowTitle(
            QCoreApplication.translate("RGB", u"RGB\u8c03\u8272\u677f", None))
        self.label.setText(QCoreApplication.translate("RGB", u"", None))
        self.label_r.setText(QCoreApplication.translate("RGB", u"0", None))
        self.label_g.setText(QCoreApplication.translate("RGB", u"0", None))
        self.label_b.setText(QCoreApplication.translate("RGB", u"0", None))
    # retranslateUi


class RGB(QMainWindow, Ui_RGB):
    def __init__(self):
        super().__init__()
        self.setupUi(self)
        self.setup()
        self.show()

    def setup(self):
        self.slider_b.valueChanged.connect(self.process)
        self.slider_r.valueChanged.connect(self.process)
        self.slider_g.valueChanged.connect(self.process)
        self.label.setScaledContents(True)

    def process(self):
        value_r = self.slider_r.value()
        value_g = self.slider_g.value()
        value_b = self.slider_b.value()
        self.label_b.setText(str(value_b))
        self.label_g.setText(str(value_g))
        self.label_r.setText(str(value_r))
        rgb = (value_r, value_g, value_b)
        self.lineEdit.setText(str(rgb))
        img = Image.new("RGBA", (100, 100), rgb)
        img = ImageQt.ImageQt(img)
        img = QPixmap.fromImage(img)
        self.label.setPixmap(img)


def main():
    app = QApplication(sys.argv)
    window = RGB()
    sys.exit(app.exec_())


if __name__ == "__main__":
    main()



from PIL import Image, ImageOps, ImageEnhance
import sys
from PySide6.QtWidgets import*
from PySide6.QtCore import*
from PySide6.QtGui import*


class Fix:
    def analyse_code(self, contents: str) -> tuple:
        lines = contents.splitlines(keepends=True)
        # locate pyside_package_dir line index
        pkg_dir = 'os.path.abspath(os.path.dirname(__file__))'
        for index, line in enumerate(lines):
            if pkg_dir in line:
                break

        # return lines, line index, indentation
        return lines, index, ' ' * (len(line.rstrip()) - len(line.strip()))

    def insert_lines(self, contents: str) -> list:
        lines, position, indentation = self.analyse_code(contents)
        new_lines = (
                lines[position] + '\n' +
                indentation + '# add platforms plugin to PATH\n' +
                indentation + 'platforms_dir = ' +
                'os.path.join(pyside_package_dir, "plugins", "platforms")\n' +
                indentation +
                'os.environ["QT_QPA_PLATFORM_PLUGIN_PATH"] = platforms_dir\n')

        # insert lines
        lines[position] = new_lines
        return lines

    def add_plugins_to_PATH(self, file_path):
        # open __init__.py
        with open(file_path, encoding='utf-8') as f:
            contents = f.read()

        # insert lines
        lines = self.insert_lines(contents)

        # save changes to __init__.py
        code = ''.join(lines)
        with open(file_path, 'w', encoding='utf-8') as f:
            f.write(code)

    def start_fix(self):
        """Glitch fixing entry."""
        import PySide6
        PySide6_init_module = PySide6.__file__
        self.add_plugins_to_PATH(PySide6_init_module)


fix = Fix()
fix.start_fix()


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        if not MainWindow.objectName():
            MainWindow.setObjectName(u"MainWindow")
        MainWindow.resize(800, 600)
        self.centralwidget = QWidget(MainWindow)
        self.centralwidget.setObjectName(u"centralwidget")
        self.Open_BTN = QPushButton(self.centralwidget)
        self.Open_BTN.setObjectName(u"Open_BTN")
        self.Open_BTN.setGeometry(QRect(100, 130, 92, 28))
        self.if_open = QLabel(self.centralwidget)
        self.if_open.setObjectName(u"if_open")
        self.if_open.setGeometry(QRect(330, 170, 91, 21))
        self.if_open.setAlignment(Qt.AlignCenter)
        self.R_Slider = QSlider(self.centralwidget)
        self.R_Slider.setObjectName(u"R_Slider")
        self.R_Slider.setGeometry(QRect(220, 210, 391, 21))
        self.R_Slider.setMinimum(-255)
        self.R_Slider.setMaximum(255)
        self.R_Slider.setOrientation(Qt.Horizontal)
        self.G_Slider = QSlider(self.centralwidget)
        self.G_Slider.setObjectName(u"G_Slider")
        self.G_Slider.setGeometry(QRect(220, 250, 391, 21))
        self.G_Slider.setMinimum(-255)
        self.G_Slider.setMaximum(255)
        self.G_Slider.setOrientation(Qt.Horizontal)
        self.B_Slider = QSlider(self.centralwidget)
        self.B_Slider.setObjectName(u"B_Slider")
        self.B_Slider.setGeometry(QRect(220, 290, 391, 21))
        self.B_Slider.setMinimum(-255)
        self.B_Slider.setMaximum(255)
        self.B_Slider.setOrientation(Qt.Horizontal)
        self.R_label = QLabel(self.centralwidget)
        self.R_label.setObjectName(u"R_label")
        self.R_label.setGeometry(QRect(120, 210, 72, 15))
        self.G_label = QLabel(self.centralwidget)
        self.G_label.setObjectName(u"G_label")
        self.G_label.setGeometry(QRect(120, 250, 72, 15))
        self.B_label = QLabel(self.centralwidget)
        self.B_label.setObjectName(u"B_label")
        self.B_label.setGeometry(QRect(120, 290, 72, 15))
        self.progressBar = QProgressBar(self.centralwidget)
        self.progressBar.setObjectName(u"progressBar")
        self.progressBar.setGeometry(QRect(110, 490, 561, 23))
        self.progressBar.setValue(0)
        self.Render_BTN = QPushButton(self.centralwidget)
        self.Render_BTN.setObjectName(u"Render_BTN")
        self.Render_BTN.setGeometry(QRect(190, 430, 91, 31))
        self.checkBox = QCheckBox(self.centralwidget)
        self.checkBox.setObjectName(u"checkBox")
        self.checkBox.setGeometry(QRect(570, 130, 181, 31))
        self.Contrast_Slider = QSlider(self.centralwidget)
        self.Contrast_Slider.setObjectName(u"Contrast_Slider")
        self.Contrast_Slider.setGeometry(QRect(220, 330, 391, 21))
        self.Contrast_Slider.setMinimum(0)
        self.Contrast_Slider.setMaximum(3000)
        self.Contrast_Slider.setValue(1000)
        self.Contrast_Slider.setOrientation(Qt.Horizontal)
        self.Contrast = QLabel(self.centralwidget)
        self.Contrast.setObjectName(u"Contrast")
        self.Contrast.setGeometry(QRect(120, 330, 72, 15))
        self.Brightness_Slider = QSlider(self.centralwidget)
        self.Brightness_Slider.setObjectName(u"Brightness_Slider")
        self.Brightness_Slider.setGeometry(QRect(220, 370, 391, 21))
        self.Brightness_Slider.setMinimum(0)
        self.Brightness_Slider.setMaximum(3000)
        self.Brightness_Slider.setValue(1000)
        self.Brightness_Slider.setOrientation(Qt.Horizontal)
        self.Brightness = QLabel(self.centralwidget)
        self.Brightness.setObjectName(u"Brightness")
        self.Brightness.setGeometry(QRect(120, 370, 81, 16))
        self.Save_BTN = QPushButton(self.centralwidget)
        self.Save_BTN.setObjectName(u"Save_BTN")
        self.Save_BTN.setGeometry(QRect(450, 430, 91, 31))
        self.title_label = QLabel(self.centralwidget)
        self.title_label.setObjectName(u"title_label")
        self.title_label.setGeometry(QRect(240, 120, 301, 41))
        font = QFont()
        font.setPointSize(16)
        self.title_label.setFont(font)
        self.title_label.setAlignment(Qt.AlignCenter)
        MainWindow.setCentralWidget(self.centralwidget)

        self.retranslateUi(MainWindow)

        QMetaObject.connectSlotsByName(MainWindow)
    # setupUi

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QCoreApplication.translate("MainWindow",
                                                             u"MainWindow", None))
        self.Open_BTN.setText(QCoreApplication.translate("MainWindow",
                                                         u"\u6253\u5f00\u56fe\u7247", None))
        self.if_open.setText("")
        self.R_label.setText(QCoreApplication.translate("MainWindow",
                                                        u"\u7ea2\u8272(R)", None))
        self.G_label.setText(QCoreApplication.translate("MainWindow",
                                                        u"\u7eff\u8272(G)", None))
        self.B_label.setText(
            QCoreApplication.translate("MainWindow",
                                       u"\u84dd\u8272(B)", None))
        self.Render_BTN.setText(
            QCoreApplication.translate("MainWindow",
                                       u"\u5f00\u59cb\u6e32\u67d3", None))
        self.checkBox.setText(
            QCoreApplication.translate("MainWindow",
                                       u"\u80f6\u5377\u6a21\u5f0f", None))
        self.Contrast.setText(QCoreApplication.translate("MainWindow",
                                                         u"\u5bf9\u6bd4\u5ea6", None))
        self.Brightness.setText(QCoreApplication.translate("MainWindow",
                                                           u"\u660e\u4eae\u5ea6", None))
        self.Save_BTN.setText(QCoreApplication.translate("MainWindow",
                                                         u"\u4fdd\u5b58\u56fe\u7247", None))
        self.title_label.setText(
            QCoreApplication.translate("MainWindow",
                                       u"\u56fe\u7247\u6e32\u67d3\u5c0f\u5de5\u5177", None))
    # retranslateUi


class RenderPicture(QMainWindow, Ui_MainWindow):
    def __init__(self):
        super().__init__()
        self.setupUi(self)
        self.setup()
        self.show()
        self.data_file = None
        self.save_file = None
        self.pic = None

    def setup(self):
        self.Open_BTN.clicked.connect(self.open_pic)
        self.Render_BTN.clicked.connect(self.render_pic)
        self.Save_BTN.clicked.connect(self.save_pic)

    def open_pic(self):
        self.data_file, _ = QFileDialog.getOpenFileName(caption="选择图片文件",
                                                        filter="(*.jpg *.png *.jpeg)")
        if self.data_file:
            self.if_open.setText("获取成功!")
        else:
            QMessageBox.warning(self, "注意", "没有打开图片!")

    def save_pic(self):
        self.save_file, _ = QFileDialog.getSaveFileName(caption="保存图片文件",
                                                        filter="(*.png *.jpg *.jpeg)")
        if self.pic:
            self.pic.save(self.save_file)
        else:
            QMessageBox.warning(self, "注意", "没有图片可保存!")

    def render_pic(self):
        if self.data_file:
            self.pic = Image.open(self.data_file).convert("RGB")
            if self.checkBox.isChecked():
                self.pic = ImageOps.invert(self.pic)

            r = self.R_Slider.value()
            g = self.G_Slider.value()
            b = self.B_Slider.value()
            old = 0
            width, height = self.pic.size
            for y in range(height):
                for x in range(width):
                    value = list(self.pic.getpixel((x, y)))
                    value[0] += r
                    value[1] += g
                    value[2] += b
                    self.pic.putpixel((x, y), tuple(value))
                process = int((y+1)*100 / height)
                if process != old:
                    self.progressBar.setValue(process)
                    old = process
            Con = self.Contrast_Slider.value()
            self.pic = ImageEnhance.Contrast(self.pic).enhance(Con / 1000)
            Bri = self.Brightness_Slider.value()
            self.pic = ImageEnhance.Brightness(self.pic).enhance(Bri / 1000)
            self.pic.show()


def main():
    app = QApplication(sys.argv)
    window = RenderPicture()
    sys.exit(app.exec_())


if __name__ == "__main__":
    main()

